@@ -1,8 +1,5 @@
-from __future__ import absolute_import
-
 # standard library
 import os
-import subprocess
 import tempfile
 import unittest
 
